--- a/doc/devtodo.1.in
+++ b/doc/devtodo.1.in
@@ -20,9 +20,6 @@
 .TP 
 \fBtdd \fI<indices>\fP\fP
 Mark the specified items as being done.
-.TP 
-\fBtdl [\-g \fI<index>\fP] \fI<database>\fP\fP
-Link the specified devtodo database into the current one, optionally grafting it as a child of the specified index.
 .SH "DESCRIPTION"
 .LP 
 \fBtodo\fP is a program aimed specifically at programmers (but usable by anybody at the terminal) to aid in day\-to\-day development.
@@ -372,6 +369,10 @@
 .TP 
 \fB~/.todorc\fR
 User-specific options are specified in this file. Please refer to the section \fBTODORC\fR for more information.
+.SH "BUGS"
+.LP
+Because of a conflict with app-misc/tdl, the tdl symbolic link and the tdl manual page have been removed.
+See \fIhttp://bugs.gentoo.org/show_bug.cgi?id=55371\fR for more information.
 .SH "AUTHORS"
 .LP 
 Alec Thomas \fI<alec@swapoff.org>\fR
--- a/doc/Makefile.am
+++ b/doc/Makefile.am
@@ -1,5 +1,5 @@
 man_MANS=devtodo.1
-manlinks=tda tdr tdd tde tdl todo
+manlinks=tda tdr tdd tde todo
 
 install-data-local:
 	mkdir -p $(DESTDIR)$(mandir)/man1
--- a/src/TodoDB.cc
+++ b/src/TodoDB.cc
@@ -949,7 +948,11 @@
 	if (out.bad()) 
 		throw exception("couldn't open TODO for generation");
 
-	if (titleText != "") wraptext(out, titleText, 0, options.columns);
+	if (titleText != "") {
+	    wraptext(out, titleText, 0, options.columns);
+	    out << endl << endl;
+	}
+
 	if (options.verbose > 1)
 		cout << "todo: generating using format '" << options.format["verbose-generated"] << "'" << endl;
 	filterView();
--- a/contrib/devtodo.bash-completion
+++ b/contrib/devtodo.bash-completion
@@ -35,6 +35,6 @@ _devtodo() {
             ;;
     esac
 }
-complete -o filenames -F _devtodo devtodo todo tda tde tdr tdd tdl
+complete -o filenames -F _devtodo devtodo todo tda tde tdr tdd
 
 # vim: set ft=sh tw=80 sw=4 et :
--- a/src/support.cc
+++ b/src/support.cc
@@ -289,11 +289,10 @@ enum { Help = -100, Remove, Version, Tit
 					<< "Where <arguments> can be any of the following:" << endl;
 				args.displayHelp(cout, options.columns);
 				cout << endl
-					<< "In addition, there are five convenience symlinks. These are 'tda', 'tdr'," << endl
-					<< "'tdd', 'tde', and 'tdl'. For 'tde', 'tdd' and 'tdr' supply an index to edit," << endl
+					<< "In addition, there are four convenience symlinks. These are 'tda', 'tdr'," << endl
+					<< "'tdd', and 'tde'. For 'tde', 'tdd' and 'tdr' supply an index to edit," << endl
 					<< "mark done and remove respectively. For 'tda' supply the text of the todo item" << endl
-					<< "item and optionally the priority. For 'tdl' supply the path to another todo" << endl
-					<< "file to link in to the current todo file." << endl
+					<< "item and optionally the priority." << endl
 					<< "eg. tde 1" << endl;
 				exit(0);
 			break;
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -1,7 +1,7 @@
 bin_PROGRAMS=devtodo
 devtodo_SOURCES=Todo.cc Todo.h TodoDB.cc TodoDB.h support.cc support.h \
 	main.cc todoterm.cc todoterm.h Loaders.cc Loaders.h todorl.h
-binlinks=tda tdr tdd tdl tde todo
+binlinks=tda tdr tdd tde todo
 	
 devtodo_LDADD=../util/libutil.la
 INCLUDES=-I../util
